unit Main;

interface

uses
  System.SysUtils, System.Types, System.UITypes, System.Classes, System.Variants,
  FMX.Types, FMX.Controls, FMX.Forms, FMX.Graphics, FMX.Dialogs, FMX.Objects,
  FMX.Controls.Presentation, FMX.StdCtrls, FSvgCanvas;

type
  TFormMain = class(TForm)
    ToolBar: TToolBar;
    PaintBox: TPaintBox;
    ButtonSaveSvg: TButton;
    procedure PaintBoxPaint(Sender: TObject; Canvas: TCanvas);
    procedure ButtonSaveSvgClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    WriteSvg: Boolean;
    procedure DrawPicture(Canvas: TSvgCanvas);
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

implementation

uses System.Math.Vectors, System.IOUtils;

{$R *.fmx}

procedure TFormMain.FormCreate(Sender: TObject);
begin
  TSvgCanvas.Create(nil, Canvas).Free; // show trial message before painting
end;

procedure TFormMain.PaintBoxPaint(Sender: TObject; Canvas: TCanvas);
var
  FileName: string;
  SvgCanvas: TSvgCanvas;
begin
  // draw white background
  with Canvas do
  try
    BeginScene;
    ClearRect(PaintBox.ClipRect, TAlphaColorRec.White);
  finally
    EndScene;
  end;

  if WriteSvg then
    FileName := TPath.Combine({$ifdef ANDROID} TPath.GetSharedDocumentsPath {$else} TPath.GetDocumentsPath {$endif}, 'picture.svg')
  else
    FileName := '';

  SvgCanvas := TSvgCanvas.Create(FileName, Canvas);
  try
    DrawPicture(SvgCanvas);
  finally
    SvgCanvas.Free;
  end;

  WriteSvg := False;
end;

procedure TFormMain.DrawPicture(Canvas: TSvgCanvas);
var Points: TPolygon;
begin
  with Canvas do
  try
    BeginScene;

    Stroke.Kind := TBrushKind.Solid;
    Stroke.Thickness := 2;

    // line
    Stroke.Color := TAlphaColorRec.Yellow;
    DrawLine(TPointF.Create(50, 80), TPointF.Create(200, 80));

    // rectangle
    Fill.Color := TAlphaColorRec.Lightgreen;
    FillRect(TRectF.Create(250, 50, 450, 120), 0, 0, []);
    Stroke.Color := TAlphaColorRec.Green;
    DrawRect(TRectF.Create(250, 50, 450, 120), 0, 0, []);

    // ellipse
    Fill.Color := TAlphaColorRec.Lightpink;
    FillEllipse(TRectF.Create(50, 150, 200, 220));
    Stroke.Color := TAlphaColorRec.Red;
    DrawEllipse(TRectF.Create(50, 150, 200, 220));

    // triangle
    SetLength(Points, 3);
    Points[0] := Point(250, 220);
    Points[1] := Point(450, 220);
    Points[2] := Point(350, 150);
    Fill.Color := TAlphaColorRec.Lightblue;
    FillPolygon(Points);
    Stroke.Color := TAlphaColorRec.Blue;
    DrawPolygon(Points);
  finally
    EndScene;
  end;
end;

procedure TFormMain.ButtonSaveSvgClick(Sender: TObject);
begin
  WriteSvg := True;
  PaintBox.Repaint;
end;

end.
